##
##  k9s.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package versions
%define       V_k9s_base  0.32.4
%define       V_k9s_snap  20240322

#   package information
Name:         k9s
Summary:      Kubernetes Command-Line User Interface (CUI)
URL:          https://k9scli.io/
Vendor:       Imhotep Software LLC
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Filesystem
License:      Apache
Version:      %{V_k9s_base}.%{V_k9s_snap}
Release:      20240322

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/k9s/k9s-%{V_k9s_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    K9S provides a terminal UI to interact with your Kubernetes
    clusters. The aim of this project is to make it easier to navigate,
    observe and manage your applications in the wild. K9s continually
    watches Kubernetes for changes and offers subsequent commands to
    interact with your observed resources.

%track
    prog k9s = {
        version   = %{V_k9s_base}
        url       = https://github.com/derailed/k9s/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n k9s
    chmod -R a+rw .

%build
    #   build package
    export GOPATH=`pwd`
    cd $GOPATH/src/github.com/derailed/k9s
    go build -v -o k9s .

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/derailed/k9s/k9s \
        $RPM_BUILD_ROOT%{l_prefix}/bin/k9s

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

